Muscle class

Constructors

Muscle({required String id, required String title, required Path path, MuscleIntensity intensity = MuscleIntensity.none})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
intensity ↔ MuscleIntensity
getter/setter pair
path ↔ Path
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited