MusclePickerMap class

Inheritance

Constructors

MusclePickerMap({Key? key, required String map, required dynamic onChanged(Set<Muscle> muscles), double? width, double? height, Color? strokeColor, Color? selectedColor, Map<String, Color>? muscleColors, Color? dotColor, bool? actAsToggle, bool? isEditing = false, Set<Muscle>? initialSelectedMuscles, List<String>? initialSelectedGroups, bool enableCrossfade = true, Duration crossfadeDuration = const Duration(milliseconds: 100), double strokeWidth = 1.0, StrokeCap? strokeCap, StrokeJoin? strokeJoin, bool showSkeleton = true, WidgetBuilder? loadingBuilder, Color? skeletonColor, Duration skeletonAnimationDuration = const Duration(milliseconds: 900), double skeletonOpacityBegin = 0.4, double skeletonOpacityEnd = 1.0, Curve skeletonCurve = Curves.easeInOut, double skeletonBorderRadius = 16})
const

Properties

actAsToggle → bool?
final
crossfadeDuration → Duration
final
dotColor → Color?
final
enableCrossfade → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
initialSelectedGroups → List<String>?
final
initialSelectedMuscles → Set<Muscle>?
final
isEditing → bool?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder → WidgetBuilder?
final
map → String
final
muscleColors → Map<String, Color>?
final
onChanged → dynamic Function(Set<Muscle> muscles)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
final
showSkeleton → bool
final
skeletonAnimationDuration → Duration
final
skeletonBorderRadius → double
final
skeletonColor → Color?
final
skeletonCurve → Curve
final
skeletonOpacityBegin → double
final
skeletonOpacityEnd → double
final
strokeCap → StrokeCap?
final
strokeColor → Color?
final
strokeJoin → StrokeJoin?
final
strokeWidth → double
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → MusclePickerMapState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited