Maps class
Constructors
- Maps()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- BACK_BODY → const String
- BODY → const String
-
female
→ const List<
String> - Female maps, ordered full / front / back. Muscle ids are identical to male, so the two sets are interchangeable at runtime.
- FEMALE_BACK_BODY → const String
- FEMALE_BODY → const String
- FEMALE_FRONT_BODY → const String
- FRONT_BODY → const String
-
male
→ const List<
String> - Male maps, ordered full / front / back.